==> auth-2.4.0304.2.1-sources.jar: com/zing/zalo/zalosdk/oauth/LocalizedString.java <==
package com.zing.zalo.zalosdk.oauth;

public class LocalizedString {
    protected String cancelMessage;
    private String errorWebViewMessage;
    protected String installMessage;
    protected String loadingMessage;
    protected String noNetworkMessage;
    protected String updateMessage;
    protected String zaloNotInstalledMessage;
    protected String zaloOauthOfDateMessage;

    public String getLoadingMessage() {
        return this.loadingMessage;
    }

    public String getNoNetworkMessage() {
        return this.noNetworkMessage;
    }

    public String getZaloOauthOfDateMessage() {
        return this.zaloOauthOfDateMessage;
    }

    public String getZaloNotInstalledMessage() {
        return this.zaloNotInstalledMessage;
    }

    public String getUpdateMessage() {
        return this.updateMessage;
    }

    public String getInstallMessage() {
        return this.installMessage;
    }

    public String getCancelMessage() {
        return this.cancelMessage;
    }

    public LocalizedString() {
        setDefault();
        customizeString();
    }

    protected void customizeString() {
    }

    private void setDefault() {
        this.loadingMessage = "Đang tải...";
        this.noNetworkMessage = "Mạng không ổn định, vui lòng thử lại sau";
        this.zaloOauthOfDateMessage = "Bản Zalo hiện tại không tương thích!";
        this.zaloNotInstalledMessage = "Bạn chưa cài Zalo!";
        this.updateMessage = "Cập nhật";
        this.cancelMessage = "Bỏ qua";
        this.installMessage = "Cài đặt";
        this.errorWebViewMessage = "Lỗi đăng nhập WebView. Vui lòng cài đặt zalo để đăng nhập.";
    }

    public String getErrorWebViewMessage() {
        return this.errorWebViewMessage;
    }

    public void setErrorWebViewMessage(String errorWebViewMessage) {
        this.errorWebViewMessage = errorWebViewMessage;
    }
}

==> auth-2.4.0717-sources.jar: com/zing/zalo/zalosdk/oauth/LocalizedString.java <==
package com.zing.zalo.zalosdk.oauth;

public class LocalizedString {
    protected String cancelMessage;
    protected String errorWebViewMessage = "";
    protected String installMessage;
    protected String loadingMessage;
    protected String noNetworkMessage;
    protected String updateMessage;
    protected String zaloNotInstalledMessage;
    protected String zaloOauthOfDateMessage;

    public String getLoadingMessage() {
        return this.loadingMessage;
    }

    public String getNoNetworkMessage() {
        return this.noNetworkMessage;
    }

    public String getZaloOauthOfDateMessage() {
        return this.zaloOauthOfDateMessage;
    }

    public String getZaloNotInstalledMessage() {
        return this.zaloNotInstalledMessage;
    }

    public String getUpdateMessage() {
        return this.updateMessage;
    }

    public String getInstallMessage() {
        return this.installMessage;
    }

    public String getCancelMessage() {
        return this.cancelMessage;
    }

    public String getErrorWebViewMessage() {
        return this.errorWebViewMessage;
    }

    public LocalizedString() {
        setDefault();
        customizeString();
    }

    protected void customizeString() {
    }

    private void setDefault() {
        this.loadingMessage = "Đang tải...";
        this.noNetworkMessage = "Mạng không ổn định, vui lòng thử lại sau";
        this.zaloOauthOfDateMessage = "Bản Zalo hiện tại không tương thích!";
        this.zaloNotInstalledMessage = "Bạn chưa cài Zalo!";
        this.updateMessage = "Cập nhật";
        this.cancelMessage = "Bỏ qua";
        this.installMessage = "Cài đặt";
        this.errorWebViewMessage = "Lỗi WebView. Vui lòng cài đặt Zalo để đăng nhập.";
    }
}
